@@ -54,13 +54,13 @@ setopt_gdbm_setcachesize (GDBM_FILE dbf, void *optval, int optlen)
 {
   size_t sz;
 
-  /* Optval will point to the new size of the cache. */
   if (dbf->bucket_cache != NULL)
     {
       GDBM_SET_ERRNO (dbf, GDBM_OPT_ALREADY_SET, FALSE);
       return -1;
     }
   
+  /* Optval will point to the new size of the cache. */
   if (get_size (optval, optlen, &sz))
     {     
       GDBM_SET_ERRNO (dbf, GDBM_OPT_ILLEGAL, FALSE);
@@ -190,7 +190,7 @@ setopt_gdbm_setmmap (GDBM_FILE dbf, void *optval, int optlen)
       GDBM_SET_ERRNO (dbf, GDBM_OPT_ILLEGAL, FALSE);
       return -1;
     }
-  __fsync (dbf);
+  gdbm_file_sync (dbf);
   if (n == dbf->memory_mapping)
     return 0;
   if (n)
@@ -248,6 +248,7 @@ setopt_gdbm_getmaxmapsize (GDBM_FILE dbf, void *optval, int optlen)
   *(size_t*) optval = dbf->mapped_size_max;
   return 0;
 }
+#endif
 
 static int
 setopt_gdbm_getflags (GDBM_FILE dbf, void *optval, int optlen)
@@ -270,7 +271,6 @@ setopt_gdbm_getflags (GDBM_FILE dbf, void *optval, int optlen)
     }
   return 0;
 }
-#endif
 
 static int
 setopt_gdbm_getdbname (GDBM_FILE dbf, void *optval, int optlen)
@@ -323,8 +323,8 @@ static setopt_handler setopt_handler_tab[] = {
   [GDBM_GETMMAP]         = setopt_gdbm_getmmap,
   [GDBM_SETMAXMAPSIZE]   = setopt_gdbm_setmaxmapsize,
   [GDBM_GETMAXMAPSIZE]   = setopt_gdbm_getmaxmapsize,
-  [GDBM_GETFLAGS]        = setopt_gdbm_getflags,
 #endif
+  [GDBM_GETFLAGS]        = setopt_gdbm_getflags,
   [GDBM_GETDBNAME]       = setopt_gdbm_getdbname,
   [GDBM_GETBLOCKSIZE]    = setopt_gdbm_getblocksize,
 };
